@@ -1,16 +1,12 @@
-from type_infer.dtype import dtype
 from lightwood.api.types import (
     JsonAI,
-    StatisticalAnalysis,
     ProblemDefinition,
     TimeseriesSettings,
     ModelAnalysis,
-    DataAnalysis,
     PredictionArguments,
 )
 from lightwood.api.predictor import PredictorInterface
 from lightwood.api.high_level import (
-    analyze_dataset,
     code_from_problem,
     predictor_from_problem,
     predictor_from_code,
@@ -21,21 +17,17 @@ from lightwood.api.high_level import (
 )
 
 __all__ = [
-    "analyze_dataset",
     "code_from_problem",
     "predictor_from_problem",
     "predictor_from_code",
     "code_from_json_ai",
     "json_ai_from_problem",
     "JsonAI",
-    "StatisticalAnalysis",
     "ProblemDefinition",
     "TimeseriesSettings",
     "ModelAnalysis",
-    "DataAnalysis",
     "PredictionArguments",
     "PredictorInterface",
-    "dtype",
     "predictor_from_state",
     "load_custom_module",
 ]
