@@ -1,7 +1,11 @@
 import random
 import torch
 import numpy as np
-import mxnet as mx
+
+try:
+    import mxnet as mx
+except Exception:
+    mx = None
 
 
 def seed(seed_nr: int) -> None:
@@ -10,4 +14,6 @@ def seed(seed_nr: int) -> None:
     torch.backends.cudnn.benchmark = False
     np.random.seed(seed_nr)
     random.seed(seed_nr)
-    mx.random.seed(seed_nr)
+
+    if mx is not None:
+        mx.random.seed(seed_nr)
