@@ -18,7 +18,8 @@ def get_ts_groups(df: pd.DataFrame, tss) -> list:
 def get_group_matches(
         data: Union[pd.Series, pd.DataFrame],
         combination: tuple,
-        group_columns: List[str]
+        group_columns: List[str],
+        copy: bool = False
 ) -> Tuple[list, pd.DataFrame]:
     """Given a particular group combination, return the data subset that belongs to it."""
 
@@ -34,6 +35,8 @@ def get_group_matches(
         for val, col in zip(combination, group_columns):
             subset = subset[subset[col] == val]
         if len(subset) > 0:
+            if copy:
+                subset = subset.copy()
             return list(subset.index), subset
         else:
             return [], pd.DataFrame()
