@@ -85,7 +85,7 @@ class LightGBMArray(BaseMixer):
             log.warning('This model does not output probability estimates')
 
         original_df = deepcopy(ds.data_frame)
-        length = sum(ds.encoded_ds_lenghts) if isinstance(ds, ConcatedEncodedDs) else len(ds)
+        length = sum(ds.encoded_ds_lengths) if isinstance(ds, ConcatedEncodedDs) else len(ds)
         ydf = pd.DataFrame(0,  # zero-filled
                            index=np.arange(length),
                            columns=[f'prediction_{i}' for i in range(self.horizon)])
